pub struct ControlCharError {
pub byte_index: usize,
pub character: char,
}Expand description
An error indicating that a control character was found in a string when constructing
a [SafeString].
Fields
byte_index: usizeThe byte index in the string where the first control character was encountered.
character: charThe control character that was encountered.
Implementations