pub struct DotCharError {
pub byte_index: usize,
pub character: char,
}Expand description
An error indicating that an unsafe DOT character was found in a string when constructing
a DotSafe.
Fields
byte_index: usizeThe byte index in the string where the first unsafe character was encountered.
character: charThe unsafe character that was encountered.
Implementations
Sourceimpl DotCharError
impl DotCharError